pub struct DetailedLinkOutput {
pub output: LinkOutput,
pub artifact_libraries: BTreeMap<ArtifactId, Libraries>,
pub artifact_addresses: BTreeMap<ArtifactId, Address>,
pub linked_libraries: Vec<LinkedLibrary>,
}Expand description
Detailed linker output for callers that need metadata about auto-linked libraries.
Fields
output: LinkOutputThe backwards-compatible linker output.
artifact_libraries: BTreeMap<ArtifactId, Libraries>Complete transitive library address mapping selected for each linked artifact.
artifact_addresses: BTreeMap<ArtifactId, Address>Address selected for every resolved library artifact, including byte-identical variants.
linked_libraries: Vec<LinkedLibrary>Unique physical library deployments and their linked creation bytecode.
Multiple byte-identical artifacts can share one CREATE2 deployment. In that case, this
contains one representative artifact while Self::artifact_addresses preserves every
artifact identity.